package com.alihealth.d2d.provtest.entity;

import com.fasterxml.jackson.annotation.*;
import com.fasterxml.jackson.databind.JsonNode;

import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @author Jason 动态字段基类
 * @date 2025年06月03日 16:49:21
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class DynamicFieldsEntity {

    // 动态字段存储
    @JsonIgnore
    protected final Map<String, Object> dynamicFields = new LinkedHashMap<>();

    // 原始数据
    @JsonIgnore
    protected JsonNode rawData;

    @JsonAnySetter
    public void setDynamicField(String name, Object value) {
        dynamicFields.put(name, value);
    }

    public Object getDynamicField(String name) {
        return dynamicFields.get(name);
    }

    @JsonAnyGetter
    public Map<String, Object> getDynamicFields() {
        return Collections.unmodifiableMap(dynamicFields);
    }

    @JsonProperty("value")
    protected void unpackNested(JsonNode node) {
        this.rawData = node;
        if (node != null) {
            node.fields().forEachRemaining(entry -> {
                dynamicFields.put(entry.getKey(),
                        entry.getValue().isValueNode() ?
                                entry.getValue().asText() :
                                entry.getValue());
            });
        }
    }

    // 实用方法
    public boolean hasField(String name) {
        return dynamicFields.containsKey(name);
    }

    public String getString(String name) {
        Object val = dynamicFields.get(name);
        return val != null ? val.toString() : null;
    }

    public Integer getInt(String name) {
        try {
            return Integer.parseInt(getString(name));
        } catch (Exception e) {
            return null;
        }
    }

    public Date getDate(String name) {
        // 实现日期转换逻辑
        return null;
    }
}
